@@ -1,6 +1,6 @@
 /* Search and replace functions
 
-   Copyright (c) 1997-2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2012 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -115,7 +115,7 @@ do_search (bool forward, bool regexp, castr pattern)
   le * ok = leNIL;
 
   if (pattern == NULL)
-    pattern = minibuf_read ("%s%s: ", astr_cstr (last_search),
+    pattern = minibuf_read ("%s%s: ", last_search ? astr_cstr (last_search) : NULL,
                             regexp ? "RE search" : "Search", forward ? "" : " backward");
 
   if (pattern == NULL)
