@@ -57,16 +57,6 @@ var_cmp (const void *v, const void *w)
   return STREQ (((const var_entry *) v)->var, ((const var_entry *) w)->var);
 }
 
-static void
-var_free (void *v)
-{
-  var_entry *p = (var_entry *) v;
-  free (p->var);
-  free (p->defval);
-  free (p->val);
-  free (p);
-}
-
 static void
 init_builtin_var (const char *var, const char *defval, bool local, const char *doc)
 {
@@ -83,7 +73,7 @@ static Hash_table *
 new_varlist (void)
 {
   /* Initial size is big enough for default variables and some more */
-  return hash_initialize (32, NULL, var_hash, var_cmp, var_free);
+  return hash_initialize (32, NULL, var_hash, var_cmp, NULL);
 }
 
 void
@@ -107,8 +97,6 @@ set_variable (const char *var, const char *val)
      create a buffer-local variable list. */
   key->var = xstrdup (var);
   ent = hash_lookup (main_vars, key);
-  free (key->var);
-  free (key);
   if (ent && ent->local && get_buffer_vars (cur_bp) == NULL)
     set_buffer_vars (cur_bp, new_varlist ());
   var_list = (ent && ent->local) ? get_buffer_vars (cur_bp) : main_vars;
@@ -118,7 +106,6 @@ set_variable (const char *var, const char *val)
   q = hash_insert (var_list, p);
 
   /* Update value */
-  free (q->val);
   q->val = xstrdup (val);
 
   /* If variable is new, initialise other fields. */
@@ -131,8 +118,6 @@ set_variable (const char *var, const char *val)
           p->doc = "";
         }
     }
-  else
-    var_free (p);
 }
 
 static var_entry *
@@ -148,8 +133,6 @@ get_variable_entry (Buffer * bp, const char *var)
   if (p == NULL)
     p = hash_lookup (main_vars, key);
 
-  var_free (key);
-
   return p;
 }
 
@@ -202,20 +185,17 @@ get_variable_bool (const char *var)
 {
   const char *p = get_variable (var);
   if (p != NULL)
-    return STRNEQ (p, "nil");
+    return !STREQ (p, "nil");
 
   return false;
 }
 
-char *
+castr
 minibuf_read_variable_name (const char *fmt, ...)
 {
-  va_list ap;
-  char *ms;
   Completion *cp = completion_new (false);
-  var_entry *p;
 
-  for (p = hash_get_first (main_vars);
+  for (var_entry *p = hash_get_first (main_vars);
        p != NULL;
        p = hash_get_next (main_vars, p))
     {
@@ -223,11 +203,12 @@ minibuf_read_variable_name (const char *fmt, ...)
                          xstrdup (p->var));
     }
 
+  va_list ap;
   va_start (ap, fmt);
-  ms = minibuf_vread_completion (fmt, "", cp, NULL,
-                                 "No variable name given",
-                                 minibuf_test_in_completions,
-                                 "Undefined variable name `%s'", ap);
+  castr ms = minibuf_vread_completion (fmt, "", cp, NULL,
+                                       "No variable name given",
+                                       minibuf_test_in_completions,
+                                       "Undefined variable name `%s'", ap);
   va_end (ap);
 
   return ms;
@@ -252,9 +233,6 @@ Set a variable value to the user-specified value.
     ok = FUNCALL (keyboard_quit);
 
   if (ok == leT)
-    set_variable (var, val);
-
-  STR_FREE (var);
-  STR_FREE (val);
+    set_variable (astr_cstr (var), astr_cstr (val));
 }
 END_DEFUN
